==> gladys-3.4.1.tgz: package/www/js/app/device/device.controller.js <==
/** 
  * Gladys Project
  * http://gladysproject.com
  * Software under licence Creative Commons 3.0 France 
  * http://creativecommons.org/licenses/by-nc-sa/3.0/fr/
  * You may not use this software for commercial purposes.
  * @author :: Pierre-Gilles Leymarie
  */
  
  
(function () {
  'use strict';

  angular
    .module('gladys')
    .controller('DeviceCtrl', DeviceCtrl);

  DeviceCtrl.$inject = ['deviceService','roomService', '$scope'];

  function DeviceCtrl(deviceService, roomService, $scope) {
    /* jshint validthis: true */
    var vm = this;
    
    vm.selectDevice = selectDevice;
    vm.changeValue = changeValue;
    vm.updateDeviceType = updateDeviceType;
    vm.changeTypeDisplay = changeTypeDisplay;
    vm.createDevice = createDevice;
    vm.deleteDevice = deleteDevice;
    vm.createDeviceType = createDeviceType;
    vm.deleteDeviceType = deleteDeviceType;

    vm.saving = false;
    vm.devices = [];
    vm.rooms = [];
    vm.selectedDevice = {
        types: []
    };
    
    vm.updateDevice = updateDevice;

    activate();

    function activate() {
      getDevices();
      getRooms();
      getDeviceTypesByRoom();
      waitForNewValue();
      return ;
    }
    
    
    function getDevices() {
      return deviceService.get()
        .then(function(data){
          vm.devices = data.data;
        });
    }
    
    function getDeviceTypesByRoom(){
       return deviceService.getDeviceTypeByRoom()
         .then(function(data){
            vm.roomDeviceTypes = data.data; 
         });
    }
    
    function getRooms(){
        return roomService.get()
          .then(function(data){
              vm.rooms = data.data;
          });
    }

    function createDevice(device){
        return deviceService.create(device)
           .then(function(data){
               vm.devices.push(data.data.device);
               vm.newDevice = {};
           });
    }

    function deleteDevice(index, id){
        return deviceService.deleteDevice(id)
          .then(function(){
              vm.devices.splice(index, 1);
          });
    }
    
    function updateDevice(device){
        console.log('Updating device ' + device.name);
        vm.saving = true;
        var newDevice = {
            id: device.id,
            room: device.room.id,
            name: device.name
        };
        return deviceService.updateDevice(newDevice)
             .then(function(device){
                 vm.saving = false;
             })
             .catch(function(err){
                vm.saving = false;
             });
    }
    
    function selectDevice(device){
        vm.selectedDevice = device;
        vm.newType = {
            device: device.id
        };
        return deviceService.getDeviceTypesDevice(device.id)
          .then(function(data){
              vm.selectedDevice.types = data.data;
          });
    }
    
    function changeValue(deviceType, value){
        return deviceService.exec(deviceType, value)
          .then(function(data){
             deviceType.lastValue = data.data.value; 
          });
    }
    
    function updateDeviceType(deviceType){
        return deviceService.updateDeviceType(deviceType)
            .then(function(){
                
            });
    }

    function createDeviceType(deviceType){
        deviceType.sensor = deviceType.sensor || false;
        return deviceService.createDeviceType(deviceType)
          .then(function(data){
              vm.selectedDevice.types.push(data.data);
               vm.newType = {
                    device: vm.selectedDevice.id
               };
          });
    }

    function deleteDeviceType(index, id){
        return deviceService.deleteDeviceType(id)
          .then(function(data){
              vm.selectedDevice.types.splice(index, 1);
          });
    }
    
    function changeTypeDisplay(type){
        if(type.display) type.display = 0;
        else type.display = 1;
        
        return updateDeviceType(type);
    }
    
     // waiting for websocket message
    function waitForNewValue(){
        
        io.socket.on('newDeviceState', function (deviceState) {
            console.log(deviceState);
            updateValueType(deviceState);
        });
    }
    
    // loop foreach device and upadte the value when the type is found
    function updateValueType(deviceState){
        var found = false;
        var i = 0;
        if(vm.selectedDevice.types){
            while(!found && i < vm.selectedDevice.types.length){

                if(vm.selectedDevice.types[i].id == deviceState.devicetype){
                    found = true;
                    vm.selectedDevice.types[i].lastValue = deviceState.value;
                    vm.selectedDevice.types[i].lastChanged = deviceState.datetime;
                    $scope.$apply();
                }
                i++;
            }
        }
    }
    
  }
})();

==> gladys-3.4.4.tgz: package/www/js/app/device/device.controller.js <==
/** 
  * Gladys Project
  * http://gladysproject.com
  * Software under licence Creative Commons 3.0 France 
  * http://creativecommons.org/licenses/by-nc-sa/3.0/fr/
  * You may not use this software for commercial purposes.
  * @author :: Pierre-Gilles Leymarie
  */
  
  
(function () {
  'use strict';

  angular
    .module('gladys')
    .controller('DeviceCtrl', DeviceCtrl);

  DeviceCtrl.$inject = ['deviceService','roomService', 'userService', '$scope'];

  function DeviceCtrl(deviceService, roomService, userService, $scope) {
    /* jshint validthis: true */
    var vm = this;
    
    vm.selectDevice = selectDevice;
    vm.changeValue = changeValue;
    vm.updateDeviceType = updateDeviceType;
    vm.changeTypeDisplay = changeTypeDisplay;
    vm.createDevice = createDevice;
    vm.deleteDevice = deleteDevice;
    vm.createDeviceType = createDeviceType;
    vm.deleteDeviceType = deleteDeviceType;

    vm.saving = false;
    vm.devices = [];
    vm.rooms = [];
    vm.users = [];
    vm.selectedDevice = {
        types: []
    };
    
    vm.updateDevice = updateDevice;

    activate();

    function activate() {
        
      // get deviceType first
      getDeviceTypesByRoom()
        .then(function(){
            getDevices();
            getRooms();
            getUsers();
        });
      waitForNewValue();
      return ;
    }
    
    
    function getDevices() {
      return deviceService.get()
        .then(function(data){
          vm.devices = data.data;
        });
    }
    
    function getDeviceTypesByRoom(){
       return deviceService.getDeviceTypeByRoom()
         .then(function(data){
            vm.roomDeviceTypes = data.data; 
         });
    }
    
    function getRooms(){
        return roomService.get()
          .then(function(data){
              vm.rooms = data.data;
              vm.rooms.unshift({id: null, name: '----'});
          });
    }

    function getUsers(){
        return userService.get()
            .then(function(data) {
                vm.users = data.data;
                vm.users.unshift({id: null, name: '----'});
            });
    }

    function createDevice(device){
        return deviceService.create(device)
           .then(function(data){
               vm.devices.push(data.data.device);
               vm.newDevice = {};
           });
    }

    function deleteDevice(index, id){
        return deviceService.deleteDevice(id)
          .then(function(){
              vm.devices.splice(index, 1);
          });
    }
    
    function updateDevice(device){
        console.log('Updating device ' + device.name);
        vm.saving = true;
        var newDevice = {
            id: device.id,
            room: device.room.id,
            user: device.user,
            name: device.name
        };
        return deviceService.updateDevice(newDevice)
             .then(function(device){
                 vm.saving = false;
             })
             .catch(function(err){
                vm.saving = false;
             });
    }
    
    function selectDevice(device){
        vm.selectedDevice = device;
        vm.newType = {
            device: device.id
        };
        return deviceService.getDeviceTypesDevice(device.id)
          .then(function(data){
              vm.selectedDevice.types = data.data;
          });
    }
    
    function changeValue(deviceType, value){
        return deviceService.exec(deviceType, value)
          .then(function(data){
             deviceType.lastValue = data.data.value; 
          });
    }
    
    function updateDeviceType(deviceType){
        return deviceService.updateDeviceType(deviceType)
            .then(function(){
                
            });
    }

    function createDeviceType(deviceType){
        deviceType.sensor = deviceType.sensor || false;
        return deviceService.createDeviceType(deviceType)
          .then(function(data){
              vm.selectedDevice.types.push(data.data);
               vm.newType = {
                    device: vm.selectedDevice.id
               };
          });
    }

    function deleteDeviceType(index, id){
        return deviceService.deleteDeviceType(id)
          .then(function(data){
              vm.selectedDevice.types.splice(index, 1);
          });
    }
    
    function changeTypeDisplay(type){
        if(type.display) type.display = 0;
        else type.display = 1;
        
        return updateDeviceType(type);
    }
    
     // waiting for websocket message
    function waitForNewValue(){
        
        io.socket.on('newDeviceState', function (deviceState) {
            updateValueType(deviceState);
        });

        io.socket.on('newDevice', function (result) {
            vm.devices.push(result.device);
            $scope.$apply();
        });
    }
    
    
    // loop foreach device and upadte the value when the type is found
    function updateValueType(deviceState){
        var found = false;
        var i = 0;
        if(vm.selectedDevice.types){
            while(!found && i < vm.selectedDevice.types.length){

                if(vm.selectedDevice.types[i].id == deviceState.devicetype){
                    found = true;
                    vm.selectedDevice.types[i].lastValue = deviceState.value;
                    vm.selectedDevice.types[i].lastChanged = deviceState.datetime;
                    $scope.$apply();
                }
                i++;
            }
        }
    }
    
  }
})();
